==> audmes_2022.10.09.orig.tar.gz: audmes-2022.10.09/event_ids.h <==
// -*- C++ -*-
// event ID list
/*
 * Copyright (C) 2008 Vaclav Peroutka <vaclavpe@seznam.cz>
 *
 * Licensed under the GNU General Public License Version 2
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

#define ID_SPANSTART 10000
#define ID_GENSTART 10001
#define ID_OSCSTART 10002
#define ID_TIMERID 10003
#define ID_GENLENB 10004
#define ID_GENRENB 10005
#define ID_GENLFREQ 10006
#define ID_GENRFREQ 10007
#define ID_GENLAMP 10008
#define ID_GENRAMP 10009
#define ID_OSCLTRIG 10010
#define ID_OSCRTRIG 10011
#define ID_FRMSTART 10012
#define ID_SNDCARD 10013
#define ID_GENSYNC 10014
#define ID_GENPHASE 10015
#define ID_OUTDEV_CHO 10016
#define ID_INDEV_CHO 10017
#define ID_TXT_FREQ_L 10018
#define ID_TXT_FREQ_R 10019
#define ID_GENSHP_L 10020
#define ID_GENSHP_R 10021
#define ID_AUTOCAL 10022
#define ID_OSCXSCALE 10023
#define ID_FFTLENGTH 10024
#define ID_FREQ_CHO 10025
#define ID_LOAD_FRM 10026
#define ID_SAVE_FRM 10027
#define ID_FFTWINDOW 10028

==> audmes_2024.02.18.orig.tar.gz: audmes-2024.02.18/event_ids.h <==
// -*- C++ -*-
// event ID list
/*
 * Copyright (C) 2008 Vaclav Peroutka <vaclavpe@seznam.cz>
 *
 * Licensed under the GNU General Public License Version 2
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

#define ID_SPANSTART 10000
#define ID_GENSTART 10001
#define ID_OSCSTART 10002
#define ID_TIMERID 10003
#define ID_GENLENB 10004
#define ID_GENRENB 10005
#define ID_GENLFREQ 10006
#define ID_GENRFREQ 10007
#define ID_GENLAMP 10008
#define ID_GENRAMP 10009
#define ID_OSCLTRIG 10010
#define ID_OSCRTRIG 10011
#define ID_FRMSTART 10012
#define ID_SNDCARD 10013
#define ID_GENSYNC 10014
#define ID_GENPHASE 10015
#define ID_OUTDEV_CHO 10016
#define ID_INDEV_CHO 10017
#define ID_TXT_FREQ_L 10018
#define ID_TXT_FREQ_R 10019
#define ID_GENSHP_L 10020
#define ID_GENSHP_R 10021
#define ID_AUTOCAL 10022
#define ID_OSCXSCALE 10023
#define ID_FFTLENGTH 10024
#define ID_FREQ_CHO 10025
#define ID_LOAD_FRM 10026
#define ID_SAVE_FRM 10027
#define ID_FFTWINDOW 10028
#define ID_FFTAVG 10029
#define ID_FFTREF 10030
#define ID_FFTDBDIV 10031
#define ID_LOAD_SPE 10032
#define ID_SAVE_SPE 10033
#define ID_SAVE_OSC 10034
